@@ -15,15 +15,15 @@ describe MailRoom::Delivery::LetterOpener do
     end
 
     it 'creates a new LetterOpener::DeliveryMethod' do
-      ::LetterOpener::DeliveryMethod.should have_received(:new).with(:location => '/tmp/somewhere')
+      expect(::LetterOpener::DeliveryMethod).to have_received(:new).with(:location => '/tmp/somewhere')
     end
 
     it 'parses the message string with Mail' do
-      ::Mail.should have_received(:read_from_string).with('a message')
+      expect(::Mail).to have_received(:read_from_string).with('a message')
     end
 
     it 'delivers the mail message' do
-      delivery_method.should have_received(:deliver!).with(mail)
+      expect(delivery_method).to have_received(:deliver!).with(mail)
     end
   end
 end
\ No newline at end of file
